package com.bsoft.api.common;

import com.bsoft.api.model.SysUser;
import com.bsoft.common.utils.JWTUtil;
import com.bsoft.common.utils.RedisUtil;

public class TokenUtil {

    public final static long TOKEN_TIME_OUT = 2L * 60 * 60;
    public final static long OLD_TOKEN_DURATION = 5L * 60;

    /**
     * 获取token，并将token存入redis
     * @param secret
     * @param user
     * @return
     */
    public static String getToken(String secret, SysUser user){
        String time = String.valueOf(System.currentTimeMillis());
        String token = JWTUtil.createTokenWithAudience(secret, time, String.valueOf(user.getId()));
        RedisUtil.set(token, user, TOKEN_TIME_OUT);
        return token;
    }

    /**
     * 刷新token，并将旧token设置过期时间为5分钟
     * @param oldToken
     * @return
     */
    public static String refresh(String oldToken){
        String token = null;
        SysUser user = (SysUser) RedisUtil.get(oldToken);
        if(user != null && JWTUtil.verifier(oldToken, user.getPassword())){
            RedisUtil.expire(oldToken, OLD_TOKEN_DURATION);
            String time = String.valueOf(System.currentTimeMillis());
            token = JWTUtil.createTokenWithAudience(user.getPassword(),time, String.valueOf(user.getId()));
        }
        return token;
    }
}
